OC.L10N.register(
    "files_external",
    {
    "Please provide a valid app key and secret." : "لطفا یک کلید و رمز معتبر برای برنامه فرآهم کنید.",
    "Step 1 failed. Exception: %s" : "گام 1 ناموفق بود. خطا: %s",
    "Step 2 failed. Exception: %s" : "گام 2ناموفق بود. خطا: %s",
    "External storage" : "حافظه خارجی",
    "Storage with id \"%i\" not found" : "فضای ذخیره‌سازی با شماره \"%i\" یافت نشد",
    "Personal" : "شخصی",
    "System" : "سیستم",
    "Grant access" : " مجوز اعطا دسترسی",
    "Access granted" : "مجوز دسترسی صادر شد",
    "Error configuring OAuth1" : "خطا پیکربندی OAuth1",
    "Error configuring OAuth2" : "خطا پیکربندی OAuth2",
    "Generate keys" : "تولید کلید",
    "Enable encryption" : "فعال کردن رمزگذاری",
    "Check for changes" : "بررسی برای تغییرات",
    "Never" : "هرگز",
    "(group)" : "(گروه)",
    "Saved" : "ذخیره شد",
    "Username" : "نام کاربری",
    "Password" : "گذرواژه",
    "Save" : "ذخیره",
    "Access key" : "کلید دسترسی",
    "Secret key" : "کلید مخفی",
    "None" : "هیچ‌کدام",
    "OAuth1" : "OAuth1",
    "App secret" : "کد برنامه",
    "OAuth2" : "OAuth2",
    "OpenStack" : "OpenStack",
    "API key" : "کلید API ",
    "Username and password" : "نام کاربری و رمز عبور",
    "Public key" : "کلید عمومی",
    "Amazon S3" : "Amazon S3",
    "Port" : "درگاه",
    "Region" : "ناحیه",
    "Enable SSL" : "فعال‌سازی SSL",
    "WebDAV" : "WebDAV",
    "URL" : "آدرس",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "میزبانی",
    "Google Drive" : "Google Drive",
    "Local" : "محلی",
    "Location" : "محل",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "اشتراک‌گذاری",
    "Domain" : "دامنه",
    "Service name" : "نام سرویس",
    "No external storage configured" : "هیچ فضای ذخیره‌سازی خارجی‌ای تنظیم نشده است",
    "Name" : "نام",
    "Storage type" : "نوع فضای ذخیره‌سازی",
    "Scope" : "حوزه",
    "External Storage" : "حافظه خارجی",
    "Folder name" : "نام پوشه",
    "Authentication" : "احراز هویت",
    "Configuration" : "پیکربندی",
    "Available for" : "در دسترس برای",
    "Add storage" : "اضافه کردن حافظه",
    "Advanced settings" : "تنظیمات پیشرفته",
    "Delete" : "حذف",
    "SMB / CIFS" : "SMB / CIFS"
},
"nplurals=1; plural=0;");
